@@ -2,6 +2,7 @@ import os
 import sys
 import time
 
+
 class Utils(object):
 
     def __init__(self, connector):
@@ -14,7 +15,7 @@ class Utils(object):
 
     def status(self):
 
-        q = [{ "GetStatus": {} }]
+        q = [{"GetStatus": {}}]
 
         try:
             res, blobs = self.connector.query(q)
@@ -30,7 +31,7 @@ class Utils(object):
 
     def get_schema(self, refresh=False):
 
-        query = [ {
+        query = [{
             "GetSchema": {
                 "refresh": refresh,
             }
@@ -53,8 +54,8 @@ class Utils(object):
         q = [{
             "CreateIndex": {
                 "index_type":    index_type,
-                "class" :        class_name,
-                "property_key" : property_key,
+                "class":        class_name,
+                "property_key": property_key,
                 "property_type": property_type
             }
         }]
@@ -172,6 +173,30 @@ class Utils(object):
 
         return total_connections
 
+    def add_descriptorset(self, name, dim, metric="L2", engine="FaissFlat"):
+
+        query = [{
+            "AddDescriptorSet": {
+                "name":       name,
+                "dimensions": dim,
+                "metric":     metric,
+                "engine":     engine
+            }
+        }]
+
+        response, arr = self.connector.query(query)
+
+        expected = [{
+            "AddDescriptorSet": {
+                "status": 0,
+            }
+        }]
+
+        if response != expected:
+            print("Error inserting set", name)
+            self.connector.print_last_response()
+
+
     def count_descriptorsets(self):
 
         q = [{
@@ -191,6 +216,29 @@ class Utils(object):
 
         return total_descriptor_sets
 
+    def get_descriptorset_list(self):
+
+        q = [{
+            "FindDescriptorSet": {
+                "results": {
+                    "all_properties": True,
+                }
+
+            }
+        }]
+
+        try:
+            res, _ = self.connector.query(q)
+
+            if not self.connector.last_query_ok():
+                self.connector.print_last_response()
+                return []
+        except:
+            self.connector.print_last_response()
+            return []
+
+        return [ent["_name"] for ent in res[0]["FindDescriptorSet"]["entities"]]
+
     def remove_descriptorset(self, set_name):
 
         q = [{
